<div style="display:none">
<form method="post" action="{% url djangospam.cookie.views.spammer_view %}">
    <label for="honeypot">Honeypot</label>
        <input id="honeypot" type="text" name="honeypot"></input>
    <label for="name">Name</label>
        <input id="name" type="text" name="name"></input>
    <label for="email">E-mail</label>
        <input id="email" type="text" name="email"></input>
    <label for="url">Website (optional)</label>
        <input id="url" type="text" name="url"></input>
    <label for="comment">Your comment</label>
        <textarea id="comment" name="comment"></textarea>
    {% csrf_token %}
    <input type="submit" value="Send"></input>
</form>
</div>